@@ -9,21 +9,21 @@
  *		   case when it is a contact.
  *  Type	-- TileType stored in a tile
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBtcontact.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBtcontact.c,v 1.3 2008/09/05 13:56:25 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -63,7 +63,7 @@ void dbTechMatchResidues();
 void dbTechAddStackedContacts();
 int dbTechAddOneStackedContact();
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -98,7 +98,7 @@ DBTechInitContact()
 
     dbNumContacts = 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -155,7 +155,7 @@ DBTechInitContact()
  *	syntax as the "contact" statement but describe a composite
  *	image such as a transistor or capacitor formed by layers on
  *	different planes.
- * 
+ *
  * Results:
  *	FALSE on error, TRUE if successful.
  *
@@ -238,7 +238,7 @@ DBTechAddContact(sectionName, argc, argv)
 				TechError("Contact type %s unknown or contact "
 					"missing in stackable statement\n", *argv);
 			    else
-				DBTechAddNameToType(*argv, newType);
+				DBTechAddNameToType(*argv, newType, FALSE);
 			    lastType = TT_SPACE;
 			}
 			else
@@ -404,7 +404,7 @@ dbTechAddOneStackedContact(type1, type2)
 
 	/* The home plane of the contact is the plane of the	*/
 	/* first shared residue found.				*/
-	
+
 	for (sres = TT_TECHDEPBASE; sres < DBNumUserLayers; sres++)
 	    if (TTMaskHasType(&ttshared, sres))
 	    {
@@ -479,13 +479,17 @@ DBMaskAddStacking(mask)
     TileTypeBitMask *mask;
 {
     TileType ttype;
+    TileTypeBitMask *rMask;
 
     for (ttype = DBNumUserLayers; ttype < DBNumTypes; ttype++)
-	if (TTMaskIntersect(DBResidueMask(ttype), mask))
+    {
+	rMask = DBResidueMask(ttype);
+	if (TTMaskIntersect(rMask, mask))
 	    TTMaskSetType(mask, ttype);
+    }
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -536,7 +540,7 @@ dbTechContactResidues(argc, argv, contactType)
 		DBTypeLongName(residueType));
 	    return -1;
 	}
- 
+
 	/*
 	 * Make sure the residue is on the same or an adjacent plane
 	 * to the contact's home type.
@@ -592,9 +596,9 @@ dbTechContactResidues(argc, argv, contactType)
     /* Ignore self */
 
     TTMaskClearType(&mmask, contactType);
-    
+
     if (!TTMaskEqual(&mmask, &DBZeroTypeBits))
-    {   
+    {
 	TxPrintf("Contact residues for %s identical to those for ",
 		DBTypeLongName(contactType));
 
@@ -603,7 +607,7 @@ dbTechContactResidues(argc, argv, contactType)
 		TxPrintf("%s ", DBTypeLongName(imageType));
 
 	TxPrintf("\n");
-    }  
+    }
 
     /* All clear to set the residue bitmask for this contact type */
 
@@ -761,13 +765,13 @@ DBTechFinalContact()
 
     /*
      * Initialize the masks of planes on which each type appears.
-     * It will contain all planes (except subcell) for space,
+     * It will contain all planes (except router) for space,
      * the home plane for each type up to DBNumTypes, and no
      * planes for undefined types.  Also update the mask of
      * types visible on each plane.
      */
 
-    DBTypePlaneMaskTbl[TT_SPACE] = ~(PlaneNumToMaskBit(PL_CELL));
+    DBTypePlaneMaskTbl[TT_SPACE] = ~(PlaneNumToMaskBit(PL_ROUTER));
     for (primaryType = 0; primaryType < DBNumTypes; primaryType++)
     {
 	pNum = DBPlane(primaryType);
@@ -891,6 +895,24 @@ DBIsContact(type)
     return FALSE;
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBLayerPlanes --
+ *
+ *   Like LayerPlaneMask(), except as a subroutine, not a macro.  For export
+ *   to other routines.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+PlaneMask
+DBLayerPlanes(type)
+    TileType type;
+{
+    return LayerPlaneMask(type);
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
