@@ -11,9 +11,9 @@
 
 typedef	struct {
 	char		typ;
-	char 		*g, *s, *d ;
+	const char	*g, *s, *d ;
 	float		l, w;
-	char 		*ga ;
+	const char	*ga ;
 	int		x, y, as, ps, ad, pd;
 }	MOS ;
 
@@ -21,8 +21,9 @@ MOS	mosFets[NSIZE];
 int	par = 0, ndx = 0;
 
 
-char *strsave(s)
-char *s;
+char *
+strsave(
+    const char *s)
 {
 	char *p ;
 
@@ -31,12 +32,14 @@ char *s;
 	return p;
 }
 
-void parseAttr(str, a, p)
-char *str;
-int *a, *p;
+void
+parseAttr(
+    const char *str,
+    int *a,
+    int *p)
 {
 	int l;
-	char *s;
+	const char *s;
 
 	if ( (l=strlen(str)) <= 2 ) {
 		*a = 0 ; *p = 0;
@@ -51,8 +54,19 @@ int *a, *p;
 			fprintf(stderr,"Weird attributes output will be incorect\n");
 }
 
-void addMos( typ, g, s, d, l, w, x, y, ga, sa, da)
-char *typ, *g, *s, *d, *l, *w, *x, *y, *ga, *sa, *da;
+void
+addMos(
+    const char *typ,
+    const char *g,
+    const char *s,
+    const char *d,
+    const char *l,
+    const char *w,
+    const char *x,
+    const char *y,
+    const char *ga,
+    const char *sa,
+    const char *da)
 {
 	int i ;
 	MOS *iptr;
@@ -107,11 +121,12 @@ char *typ, *g, *s, *d, *l, *w, *x, *y, *ga, *sa, *da;
 }
 
 
-main ()
+int
+main (int argc, char *argv[])
 {
 	int i;
 	char str[STRLEN];
-	char *typ, *g, *s, *d, *l, *w, *x, *y, *ga, *sa, *da;
+	const char *typ, *g, *s, *d, *l, *w, *x, *y, *ga, *sa, *da;
 
 
         while (fgets (str, STRLEN - 1, stdin)) {
