@@ -13,25 +13,29 @@
  * DebugIsSet().
  *
  *
- *     ********************************************************************* 
+ *     *********************************************************************
  *     * Copyright (C) 1988, 1990 Michael H. Arnold and the Regents of the *
  *     * University of California.                                         *
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  *
- * rcsid $Header: /usr/cvsroot/magic/mzrouter/mzDebug.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic-8.0/mzrouter/mzDebug.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $
  *
  */
 
+#ifndef _MAGIC__MZROUTER__MZDEBUG_H
+#define _MAGIC__MZROUTER__MZDEBUG_H
+
 extern int mzDebStep;	/* single step - pauses after each path extension,
 			   and prints statistics */
 extern int mzDebMaze;	/* traces maze router - details on selection of
 			   best path and extension from it. */
 
+#endif /* _MAGIC__MZROUTER__MZDEBUG_H */
