@@ -243,12 +243,12 @@ proc magic::drcupdate { option } {
 }
 
 proc magic::drcstate { status } {
-   logcommands suspend
+   *bypass logcommands suspend
    set winlist [*bypass windownames layout]
    foreach lwin $winlist {
       set framename [winfo parent $lwin]
       if {$framename == "."} {
-	 logcommands resume
+	 *bypass logcommands resume
 	 return
       }
       switch $status {
@@ -264,7 +264,7 @@ proc magic::drcstate { status } {
          busy { ${framename}.titlebar.drcbutton configure -selectcolor yellow }
       }
    }
-   logcommands resume
+   *bypass logcommands resume
 }
 
 # Create the menu of windows.  This is kept separate from the cell manager,
@@ -515,7 +515,7 @@ proc magic::captions {{subcommand {}}} {
    if {$subcommand != {} && $subcommand != "writeable" && $subcommand != "load"} {
       return
    }
-   logcommands suspend
+   *bypass logcommands suspend
    set winlist [magic::windownames layout]
    foreach winpath $winlist {
       set framename [winfo parent $winpath]
@@ -535,30 +535,30 @@ proc magic::captions {{subcommand {}}} {
 	   "Loaded: ${subcaption1} Editing: ${subcaption2} Tool: $Opts(tool) \
 	   Technology: ${techname}"
    }
-   logcommands resume
+   *bypass logcommands resume
 }
 
 # Allow captioning in the title window by tagging the "load" and "edit" commands
 # Note that the "box" tag doesn't apply to mouse-button events, so this function
 # is duplicated by Tk binding of mouse events in the layout window.
 
-magic::tag load "[magic::tag load]; magic::captions"
-magic::tag edit "magic::captions"
-magic::tag save "magic::captions"
-magic::tag down "magic::captions"
-magic::tag box "magic::boxview %W %1"
-magic::tag move "magic::boxview %W"
-magic::tag scroll "magic::scrollupdate %W"
-magic::tag view "magic::scrollupdate %W"
-magic::tag zoom "magic::scrollupdate %W"
-magic::tag findbox "magic::scrollupdate %W"
-magic::tag see "magic::toolupdate %W %1 %2"
-magic::tag tech "magic::techrebuild %W %1; magic::captions %1"
-magic::tag drc "magic::drcupdate %1"
-magic::tag path "[magic::tag path]; magic::techmanager update"
-magic::tag cellname "magic::mgrupdate %W %1"
-magic::tag cif      "magic::mgrupdate %W %1"
-magic::tag gds      "magic::mgrupdate %W %1"
+magic::tag add load "magic::captions"
+magic::tag add edit "magic::captions"
+magic::tag add save "magic::captions"
+magic::tag add down "magic::captions"
+magic::tag add box "magic::boxview %W %1"
+magic::tag add move "magic::boxview %W"
+magic::tag add scroll "magic::scrollupdate %W"
+magic::tag add view "magic::scrollupdate %W"
+magic::tag add zoom "magic::scrollupdate %W"
+magic::tag add findbox "magic::scrollupdate %W"
+magic::tag add see "magic::toolupdate %W %1 %2"
+magic::tag add tech "magic::techrebuild %W %1; magic::captions %1"
+magic::tag add drc "magic::drcupdate %1"
+magic::tag add path "magic::techmanager update"
+magic::tag add cellname "magic::mgrupdate %W %1"
+magic::tag add cif      "magic::mgrupdate %W %1"
+magic::tag add gds      "magic::mgrupdate %W %1"
 
 # This should be a list. . . do be done later
 set lwindow 0
@@ -670,10 +670,10 @@ proc magic::cursorview {win} {
    if {$win == {}} {
       return
    }
-   logcommands suspend
+   *bypass logcommands suspend
    set framename [winfo parent $win]
    if {[catch {set cr [*bypass cif scale out]}]} {
-      logcommands resume
+      *bypass logcommands resume
       return
    }
    if {$cr == 0} {return}
@@ -691,7 +691,7 @@ proc magic::cursorview {win} {
       set olstx [expr {$olstx * $cr}]
       set olsty [expr {$olsty * $cr}]
    }]} {
-      logcommands resume
+      *bypass logcommands resume
       return
    }
 
@@ -707,24 +707,24 @@ proc magic::cursorview {win} {
       set titletext [format "(%+g %+g) microns" $olstx $olsty]
       ${framename}.titlebar.pos configure -text $titletext
    }
-   logcommands resume
+   *bypass logcommands resume
 }
 
 proc magic::toolupdate {win {yesno "yes"} {layerlist "none"}} {
    global Winopts
 
    if {[magic::display] == "NULL"} {return}
-   logcommands suspend
+   *bypass logcommands suspend
    if {$win == {}} {
       set win [magic::windownames]
    }
 
    # Wind3d has a "see" function, so make sure this is not a 3d window
    if {$win == [magic::windownames wind3d]} {
-      logcommands resume
+      *bypass logcommands resume
       return
    }
-   logcommands resume
+   *bypass logcommands resume
 
    set topname [winfo toplevel $win]
    set framename [winfo parent $win]
@@ -760,12 +760,16 @@ proc magic::toolupdate {win {yesno "yes"} {layerlist "none"}} {
       # "hidespecial" is used, so catch each configure command.
 
       if {$canon != ""} {
-         if {$yesno == "yes"} {
-	    catch {${framename}.toolbar.b$canon configure -image img_$canon}
-	    catch {${framename}.toolbar.p$canon configure -image pale_$canon}
-         } else {
-	    catch {${framename}.toolbar.b$canon configure -image img_space}
-	    catch {${framename}.toolbar.p$canon configure -image img_space}
+         # Layer aliases like "allm1" expand into multiple layers
+         foreach clayer $canon {
+	    set toolframe ${framename}.toolbar.canvas.frame.f${clayer}
+            if {$yesno == "yes"} {
+	       catch {${toolframe}.b configure -image img_$clayer}
+	       catch {${toolframe}.p configure -image pale_$clayer}
+            } else {
+	       catch {${toolframe}.b configure -image img_space}
+	       catch {${toolframe}.p configure -image img_space}
+	    }
 	 }
       }
    }
@@ -827,13 +831,13 @@ proc magic::techrebuild {winpath {cmdstr ""}} {
 proc magic::setscrollvalues {win} {
    global Opts
 
-   logcommands suspend
+   *bypass logcommands suspend
    set svalues [${win} view get]
    set bvalues [${win} view bbox]
 
    set framename [winfo parent ${win}]
    if {$framename == "."} {
-      logcommands resume
+      *bypass logcommands resume
       return
    }
 
@@ -877,7 +881,7 @@ proc magic::setscrollvalues {win} {
 
 proc magic::scrollupdate {win} {
 
-   logcommands suspend
+   *bypass logcommands suspend
    if {[magic::display] == "NULL"} {return}
    if {[info level] <= 1} {
 
@@ -894,7 +898,7 @@ proc magic::scrollupdate {win} {
  	 magic::setscrollvalues $win
       }
    }
-   logcommands resume
+   *bypass logcommands resume
 }
 
 # scrollview:  update the magic display to match the
